<?php

namespace Drp\SimpleCms\Generators\Commands;

use Drp\SimpleCms\Generators\Crud\Core;
use Drp\SimpleCms\Generators\Crud\Simple as SimpleGenerator;
use Drp\SimpleCms\Generators\Crud\SimpleCMS as SimpleCmsGenerator;
use Illuminate\Console\Command;
use Illuminate\Support\Facades\Artisan;

class CrudGeneratorCommand extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'simple-cms:generate-crud {name} {--simple} {--simple-cms}';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Specify the model name to generate the entire crud functionality and tests';

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function handle()
    {
        $name = ucfirst($this->argument('name'));

        if (!$this->option('simple') && !$this->option('simple-cms')
            || ($this->option('simple') && $this->option('simple-cms'))
        ) {
            $this->error('You must specify --simple or --simple-cms option for your model.');
            return;
        }

        $this->info("Create $name crud functionality");

        Core::prepare();

        if ($this->option('simple')) {
            SimpleGenerator::create($name);
        } elseif ($this->option('simple-cms')) {
            SimpleCmsGenerator::create($name);
        }

        $this->info("Done.");

        if (!$this->confirm('Do you want to migrate? (y/n): ')) {
            return;
        }

        Artisan::call('migrate');
    }
}
