<?php

namespace Drp\SimpleCms\Http\Requests;

use Drp\SimpleCms\Contracts\Publishable;
use Illuminate\Foundation\Http\FormRequest;

class ContentRequest extends FormRequest implements \Drp\SimpleCms\Contracts\ContentRequest
{
    /**
     * @var array
     */
    protected $rules = [];

    /**
     * @var array
     */
    protected $messages = [];

    public function validateResolved(): void
    {
    }

    public function validate(Publishable $content): void
    {
        // phpcs:disable SlevomatCodingStandard.ControlStructures.EarlyExit.EarlyExitNotUsed
        $this->setRules($content);

        if (!$this->passesAuthorization()) {
            $this->failedAuthorization();
        }

        $instance = $this->getValidatorInstance();

        if ($instance->fails()) {
            $this->failedValidation($instance);
        }
        // phpcs:enable SlevomatCodingStandard.ControlStructures.EarlyExit.EarlyExitNotUsed
    }

    /**
     * Prepare the input using the given content.
     * Retrieves the before updated closure from the content
     * and calls it using the current request.
     *
     * @return array|string
     */
    public function prepareInput(Publishable $content): \Drp\SimpleCms\Contracts\ContentRequest
    {
        $callback = $content->getCallbackForUpdateRequest($this);

        if ($callback instanceof \Closure) {
            call_user_func($callback, $this);
        }

        return $this;
    }

    public function setRules(Publishable $content): \Drp\SimpleCms\Contracts\ContentRequest
    {
        $this->rules = $content->getSaveRules();
        $this->messages = $content->getSaveMessages();

        return $this;
    }

    public function authorize(): bool
    {
        return true;
    }

    public function rules(): array
    {
        return $this->rules;
    }

    public function messages(): array
    {
        return $this->messages;
    }
}
